@@ -1,15 +1,15 @@
 
 module Config
 
-  VERSION == "1.6.3" or
-    raise "ruby lib version (1.6.3) doesn't match executable version (#{VERSION})"
+  RUBY_VERSION == "1.6.4" or
+    raise "ruby lib version (1.6.4) doesn't match executable version (#{RUBY_VERSION})"
 
 # This file was created by configrb when ruby was built. Any changes
 # made to this file will be lost the next time ruby is built.
   DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-msdosdjgpp\Z', '')
-  CONFIG["srcdir"] = "/home/pub/ruby/16/dist/ruby-1.6.3"
+  CONFIG["srcdir"] = "/home/pub/ruby/16/dist/ruby-1.6.4"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
@@ -20,22 +20,22 @@ module Config
   CONFIG["FFLAGS"] = ""
   CONFIG["LDFLAGS"] = ""
   CONFIG["LIBS"] = "-lm "
-  CONFIG["exec_prefix"] = "#{CONFIG[\"prefix\"]}"
-  CONFIG["bindir"] = "#{CONFIG[\"exec_prefix\"]}/bin"
-  CONFIG["sbindir"] = "#{CONFIG[\"exec_prefix\"]}/sbin"
-  CONFIG["libexecdir"] = "#{CONFIG[\"exec_prefix\"]}/libexec"
-  CONFIG["datadir"] = "#{CONFIG[\"prefix\"]}/share"
-  CONFIG["sysconfdir"] = "#{CONFIG[\"prefix\"]}/etc"
-  CONFIG["sharedstatedir"] = "#{CONFIG[\"prefix\"]}/com"
-  CONFIG["localstatedir"] = "#{CONFIG[\"prefix\"]}/var"
-  CONFIG["libdir"] = "#{CONFIG[\"exec_prefix\"]}/lib"
-  CONFIG["includedir"] = "#{CONFIG[\"prefix\"]}/include"
+  CONFIG["exec_prefix"] = "$(prefix)"
+  CONFIG["bindir"] = "$(exec_prefix)/bin"
+  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
+  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
+  CONFIG["datadir"] = "$(prefix)/share"
+  CONFIG["sysconfdir"] = "$(prefix)/etc"
+  CONFIG["sharedstatedir"] = "$(prefix)/com"
+  CONFIG["localstatedir"] = "$(prefix)/var"
+  CONFIG["libdir"] = "$(exec_prefix)/lib"
+  CONFIG["includedir"] = "$(prefix)/include"
   CONFIG["oldincludedir"] = "/usr/include"
-  CONFIG["infodir"] = "#{CONFIG[\"prefix\"]}/info"
-  CONFIG["mandir"] = "#{CONFIG[\"prefix\"]}/man"
+  CONFIG["infodir"] = "$(prefix)/info"
+  CONFIG["mandir"] = "$(prefix)/man"
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "6"
-  CONFIG["TEENY"] = "3"
+  CONFIG["TEENY"] = "4"
   CONFIG["host"] = "i586-pc-msdosdjgpp"
   CONFIG["host_alias"] = "i586-pc-msdosdjgpp"
   CONFIG["host_cpu"] = "i586"
@@ -61,11 +61,10 @@ module Config
   CONFIG["AS"] = ""
   CONFIG["DLLTOOL"] = ""
   CONFIG["WINDRES"] = ""
-  CONFIG["MWIN32"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["SET_MAKE"] = ""
   CONFIG["OBJEXT"] = "o"
-  CONFIG["LIBOBJS"] = "memcmp.o crypt.o flock.o vsnprintf.o strtod.o"
+  CONFIG["LIBOBJS"] = "crypt.o flock.o vsnprintf.o strtod.o"
   CONFIG["ALLOCA"] = ""
   CONFIG["XLDFLAGS"] = ""
   CONFIG["DLDFLAGS"] = ""
@@ -77,7 +76,7 @@ module Config
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup.dj"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/djgpp -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.4/dobj -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["LIBRUBY_LDSHARED"] = "ld"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
@@ -91,17 +90,23 @@ module Config
   CONFIG["SOLIBS"] = ""
   CONFIG["DLDLIBS"] = "-lc"
   CONFIG["ENABLE_SHARED"] = "no"
+  CONFIG["MAINLIBS"] = ""
   CONFIG["arch"] = "i386-msdosdjgpp"
-  CONFIG["sitedir"] = "#{CONFIG[\"prefix\"]}/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "--target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu --cache=../config.cache-djgpp"
-  CONFIG["compile_dir"] = "/home/pub/ruby/16/dist/djgpp"
+  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
+  CONFIG["configure_args"] = "--target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu"
+  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
+  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
+  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
+  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
+  CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
+  CONFIG["compile_dir"] = "/home/pub/ruby/16/dist/ruby-1.6.4/dobj"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val)
     val.gsub!(/\$\(([^()]+)\)/) do |var|
       key = $1
       if CONFIG.key? key
-        "#{Config::expand(CONFIG[\"#{key}\"])}"
+        Config::expand(CONFIG[key])
       else
 	var
       end
